@@ -15,15 +15,31 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-#include "config.h"
+#include "common/setup_before.h"
 #ifndef HAVE_INET_NTOA
 
 #include <stdio.h>
-#include <sys/types.h>
-#include <sys/param.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
+#ifdef HAVE_STDDEF_H
+# include <stddef.h>
+#else
+# ifndef NULL
+#  define NULL ((void *)0)
+# endif
+#endif
+#ifdef HAVE_SYS_TYPES
+# include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_PARAM_H
+# include <sys/param.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
+# include <netinet/in.h>
+#endif
+#ifdef HAVE_ARPA_INET_H
+# include <arpa/inet.h>
+#endif
 #include "inet_ntoa.h"
+#include "common/setup_after.h"
 
 
 extern char const * inet_ntoa(struct in_addr const * addr)
