@@ -18,11 +18,14 @@
 #ifndef INCLUDED_INET_NTOA_H
 #define INCLUDED_INET_NTOA_H
 
-#include "config.h"
 #ifndef HAVE_INET_NTOA
 
-#include <netinet/in.h>
-#include <arpa/inet.h>
+#ifdef HAVE_NETINET_IN_H
+# include <netinet/in.h>
+#endif
+#ifdef HAVE_ARPA_INET_H
+# include <arpa/inet.h>
+#endif
 
 extern char const * inet_ntoa(struct in_addr const * addr);
 
