@@ -15,10 +15,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-#include "config.h"
+#include "common/setup_before.h"
 #ifndef HAVE_STRDUP
-
-#include "setup.h"
+#ifdef HAVE_STDDEF_H
+# include <stddef.h>
+#else
+# ifndef NULL
+#  define NULL ((void *)0)
+# endif
+#endif
 #ifdef STDC_HEADERS
 # include <stdlib.h>
 #else
@@ -34,6 +39,7 @@
 # endif
 #endif
 #include "strdup.h"
+#include "common/setup_after.h"
 
 
 extern char * strdup(char const * str)
